@@ -11,12 +11,15 @@ if ( !isGeneric("initProj") ) {
 #'
 #'@param projRootDir  project github root directory (your github name)
 #'@param projFolders list of subfolders in project
+#'@param GRASSlocation folder for GRASS data
 #'
 #'@export initProj
 #'   
 
 
-initProj <- function(projRootDir=getwd(), projFolders=c("data/","result/","run/","log/")) {
+initProj <- function(projRootDir=getwd(), 
+                     GRASSlocation = "tmp/", 
+                     projFolders=c("data/","result/","run/","log/")) {
   
   # switch backslash to slash and expand path to full path
   projRootDir <- gsub("\\\\", "/", path.expand(projRootDir))  
@@ -30,14 +33,28 @@ initProj <- function(projRootDir=getwd(), projFolders=c("data/","result/","run/"
     for (folder in projFolders) {
       if (!file.exists(file.path(projRootDir,folder))) {
         dir.create(file.path(projRootDir,folder), recursive = TRUE)
-        name <- paste0("path_",substr(folder,1,nchar(folder) - 1))
+        p<-gsub("/", "_", substr(folder,1,nchar(folder) - 1))
+        name <- paste0("path_",p)
         value <- paste0(projRootDir,folder)
         makGlobalVar(name, value)
         } else {
-        name <- paste0("path_",substr(folder,1,nchar(folder) - 1))
+        p<-gsub("/", "_", substr(folder,1,nchar(folder) - 1))
+        name <- paste0("path_",p)          
         value <- paste0(projRootDir,folder)
         makGlobalVar(name, value)
         } 
-      
     }
+  if (!file.exists(file.path(projRootDir,GRASSlocation))) {
+    dir.create(file.path(projRootDir,GRASSlocation), recursive = TRUE)
+    p<-gsub("/", "_", substr(GRASSlocation,1,nchar(GRASSlocation) - 1))
+    name <- paste0("path_",p)
+    value <- paste0(projRootDir,GRASSlocation)
+    makGlobalVar(name, value)
+  } else {
+    p<-gsub("/", "_", substr(GRASSlocation,1,nchar(GRASSlocation) - 1))
+    name <- paste0("path_",p)
+    value <- paste0(projRootDir,GRASSlocation)
+    makGlobalVar(name, value)
+  } 
+  
 }
